Bot

Struct Bot 

pub struct Bot { /* private fields */ }
Main bot class

Implementations

Source

impl Bot

pub fn builder(wiki_url: String) -> Builder

Build a Bot instance programmatically.

The wiki’s URL should be the path where api.php and rest.php can be found (aka the “script path”). By default it is usually something like https://wiki.example.org/w/.

pub fn builder_with_legacy_rest(api_url: String, rest_url: String) -> Builder

For older wikis (pre-1.42) that use RESTBase or the old Parsoid rest.php API.

pub async fn from_default_config() -> Result<Self, ConfigError>

Load Bot configuration from a default location, first look at mwbot.toml in the current directory, otherwise look in the platform’s config directory:

  • Linux: $XDG_CONFIG_HOME or $HOME/.config
  • macOS: $HOME/Library/Application Support
  • Windows: {FOLDERID_RoamingAppData}

Under UNIX-like systems, the configuration file must only be readable by its owner!

pub async fn from_path(path: &Path) -> Result<Self, ConfigError>

Load Bot configuration from the specified path.

Under UNIX-like systems, the configuration file must only be readable by its owner!

pub async fn clone_for_family( &self, wiki_url: &str, ) -> Result<Self, ConfigError>

Clone this bot for another wiki in the same family.

This allows you to use the Bot to connect to another wiki in the same family. For example, if you have a bot for en.wikipedia.org, you can clone it to use with de.wikipedia.org.

Behind the scenes, this will copy over the username, authentication info, as well as internal HTTP connection pools and save state. Rate limits like edit speed will apply across both instances.

pub async fn clone_for_family_via_dbname( &self, dbname: &str, ) -> Result<Self, ConfigError>

Available on crate feature sitematrix only.
pub fn api(&self) -> &ApiClient

Get a reference to the underlying mwapi::Client to make arbitrary API requests

pub fn parsoid(&self) -> &ParsoidClient

Get a reference to the underlying parsoid::Client to make arbitrary Parsoid API requests

pub fn title_codec(&self) -> &TitleCodec

Get a reference to the internal mwtitle::TitleCodec to parse and construct arbitrary titles.

pub fn page(&self, title: &str) -> Result<Page>

Get a Page on this wiki. The specified title should be a full title, including namespace. This does some validation on the provided input.

pub fn page_from_database(&self, namespace: i32, dbkey: &str) -> Result<Page>

Get a Page on this wiki using information from a database row.

The provided input will be validated and may return an error if invalid.

pub fn page_from_title(&self, title: Title) -> Result<Page>

Get a Page for a given Title

pub async fn page_from_id(&self, page_id: u64) -> Result<Page>

Get a Page on this wiki using page id.

The provided input will be validated and may return an error if invalid.

pub fn server_name(&self) -> &str

Get the site’s server name, which is usually the domain name, e.g. "en.wikipedia.org"

pub fn wiki_id(&self) -> &str

Get the site’s “wikiid”, which is usually the internal database name, e.g. "enwiki"

pub fn mediawiki_version(&self) -> &str

Get the version of MediaWiki that the site is using, e.g. "1.45.0"

pub fn namespace_id<'a, N: Into<Namespace<'a>>>( &self, namespace: N, ) -> Option<i32>

Get the numeric id of a Namespace.

pub fn namespace_name<'a, N: Into<Namespace<'a>>>( &self, namespace: N, ) -> Option<&str>

Get the name of a Namespace.